summaryrefslogtreecommitdiffstats
path: root/include/llvm/CodeGen/InstrSelectionSupport.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/CodeGen/InstrSelectionSupport.h')
-rw-r--r--include/llvm/CodeGen/InstrSelectionSupport.h11
1 files changed, 8 insertions, 3 deletions
diff --git a/include/llvm/CodeGen/InstrSelectionSupport.h b/include/llvm/CodeGen/InstrSelectionSupport.h
index adfad6b..3f41fb4 100644
--- a/include/llvm/CodeGen/InstrSelectionSupport.h
+++ b/include/llvm/CodeGen/InstrSelectionSupport.h
@@ -21,11 +21,13 @@ class TargetMachine;
//---------------------------------------------------------------------------
+// Function GetConstantValueAsUnsignedInt
// Function GetConstantValueAsSignedInt
//
// Convenience function to get the value of an integer constant, for an
// appropriate integer or non-integer type that can be held in an integer.
// The type of the argument must be the following:
// Signed or unsigned integer
// Boolean
// Pointer
@@ -33,6 +35,9 @@ class TargetMachine;
// isValidConstant is set to true if a valid constant was found.
//---------------------------------------------------------------------------
+uint64_t GetConstantValueAsUnsignedInt (const Value *V,
+ bool &isValidConstant);
+
int64_t GetConstantValueAsSignedInt (const Value *V,
bool &isValidConstant);
@@ -21,11 +21,13 @@ class TargetMachine;
// Function GetConstantValueAsSignedInt
//
-// Convenience function to get the value of an integer constant, for an
-// appropriate integer or non-integer type that can be held in an integer.
-// The type of the argument must be the following:
+// Convenience functions to get the value of an integer constant, for an
+// appropriate integer or non-integer type that can be held in a signed
+// or unsigned integer respectively. The type of the argument must be
+// the following:
// Signed or unsigned integer
// Boolean